@@ -1,7 +1,15 @@
 import logging
 import os
 import click
-from wordpress_markdown_blog_loader import upload, download, new
+from wordpress_markdown_blog_loader import (
+    upload,
+    download,
+    new,
+    update_canonical,
+    change_guid,
+    add_email,
+    regenerate_og_images
+)
 
 
 @click.group()
@@ -25,6 +33,10 @@ posts.add_command(upload.command)
 posts.add_command(download.command)
 posts.add_command(new.command)
 posts.add_command(new.update_banner_command)
+posts.add_command(update_canonical.command)
+posts.add_command(change_guid.command)
+posts.add_command(add_email.command)
+posts.add_command(regenerate_og_images.command)
 
 
 if __name__ == "__main__":
